@@ -175,6 +175,7 @@ static void sig_message_public(SERVER_REC *server, const char *msg,
 	int for_me, print_channel, level;
 	char *nickmode, *color, *freemsg = NULL;
 	HILIGHT_REC *hilight;
+	TEXT_DEST_REC dest;
 
 	/* NOTE: this may return NULL if some channel is just closed with
 	   /WINDOW CLOSE and server still sends the few last messages */
@@ -214,7 +215,6 @@ static void sig_message_public(SERVER_REC *server, const char *msg,
 	if (printnick == NULL)
 		printnick = nick;
 
-	TEXT_DEST_REC dest;
 	format_create_dest(&dest, server, target, level, NULL);
 	dest.address = address;
 	dest.nick = nick;
@@ -396,8 +396,9 @@ static void sig_message_quit(SERVER_REC *server, const char *nick,
 	count = 0; windows = NULL;
 	chans = g_string_new(NULL);
 	for (tmp = server->channels; tmp != NULL; tmp = tmp->next) {
+		CHANNEL_REC *rec;
 		level = MSGLEVEL_QUITS;
-		CHANNEL_REC *rec = tmp->data;
+		rec = tmp->data;
 
 		if (!nicklist_find(rec, nick))
 			continue;
